@@ -18,6 +18,7 @@ import random
 import threading
 import time
 import types
+import logging
 
 from datetime import datetime
 from functools import wraps
@@ -38,7 +39,7 @@ class SEVERITY:
     DEBUG = 7
 
 
-class TimerResult(object):
+class _TimerResult(object):
     def __init__(self, ms=None):
         self.ms = ms
 
@@ -113,7 +114,7 @@ class _Timer(object):
             return None
 
         self.start = time.time()
-        self.result = TimerResult()
+        self.result = _TimerResult()
         return self.result
 
     def __exit__(self, typ, value, tb):
@@ -174,6 +175,7 @@ class MetlogClient(object):
         if filters is None:
             filters = list()
         self.filters = filters
+        self._handler = MetlogHandler(self)
 
     def send_message(self, msg):
         """
@@ -275,20 +277,62 @@ class MetlogClient(object):
 
     # Standard Python logging API emulation
     def debug(self, msg):
+        """ Log a DEBUG level message """
         self.metlog(type='oldstyle', severity=SEVERITY.DEBUG, payload=msg)
 
     def info(self, msg):
+        """ Log a INFO level message """
         self.metlog(type='oldstyle', severity=SEVERITY.INFORMATIONAL,
                     payload=msg)
 
     def warn(self, msg):
+        """ Log a WARN level message """
         self.metlog(type='oldstyle', severity=SEVERITY.WARNING, payload=msg)
 
     def error(self, msg):
+        """ Log a ERROR level message """
         self.metlog(type='oldstyle', severity=SEVERITY.ERROR, payload=msg)
 
     def exception(self, msg):
+        """ Log a ALERT level message """
         self.metlog(type='oldstyle', severity=SEVERITY.ALERT, payload=msg)
 
     def critical(self, msg):
+        """ Log a CRITICAL level message """
         self.metlog(type='oldstyle', severity=SEVERITY.CRITICAL, payload=msg)
+
+    def _get_handler(self):
+        if self._handler is None:
+            self._handler = MetlogHandler(self)
+            self._handler.setLevel(logging.DEBUG)
+        return self._handler
+
+    def hook_logger(self, name):
+        """
+        Use this to hook metlog into the standard logging framework.
+
+        This is provided for backwards compatibility only.
+        """
+        logging.getLogger(name).addHandler(self._get_handler())
+
+
+class MetlogHandler(logging.Handler):
+    def __init__(self, metlog):
+        logging.Handler.__init__(self)
+        self.metlog = metlog
+
+    def emit(self, record):
+        if record.levelno == logging.DEBUG:
+            severity = SEVERITY.DEBUG
+        elif record.levelno == logging.INFO:
+            severity = SEVERITY.INFORMATIONAL
+        elif record.levelno == logging.WARNING:
+            severity = SEVERITY.WARNING
+        elif record.levelno == logging.ERROR:
+            severity = SEVERITY.ERROR
+        else: # critical
+            severity = SEVERITY.CRITICAL
+
+        self.metlog.metlog(type='oldstyle', severity=severity,
+                payload=record.msg)
+
