@@ -22,22 +22,26 @@ import threading
 import time
 
 
-@patch.object(ZmqPubSender, '_zmq_context')
 class TestZmqPubSender(object):
     logger = 'tests'
 
     def setUp(self):
         if zmq is None:
             raise(SkipTest)
+        self.context_patcher = patch.object(ZmqPubSender, '_zmq_context')
+        self.mock_zmq_context = self.context_patcher.start()
         self.sender = self._make_one()
 
-    def _make_one(self):
-        return ZmqPubSender(bindstrs='bindstr')
+    def tearDown(self):
+        self.mock_zmq_context.stop()
 
-    def test_publ_threadsafe(self, mock_zmq_context):
+    def _make_one(self):
+        return ZmqPubSender(bindstrs='bindstr', pool_size=2)
+
+    def test_publ_threadsafe(self):
 
         def reentrant():
-            self.sender.publisher
+            self.sender.send_message('foo')
 
         t0 = threading.Thread(target=reentrant)
         t1 = threading.Thread(target=reentrant)
@@ -46,17 +50,33 @@ class TestZmqPubSender(object):
         t1.start()
         time.sleep(0.01)  # give it time to ensure publisher is accessed
         # the socket call should have happened twice, once for each thread
-        eq_(mock_zmq_context.socket.call_count, 2)
+        mock_socket = self.mock_zmq_context.socket()
+        eq_(mock_socket.connect.call_count, 2)
+        eq_(mock_socket.send.call_count, 2)
 
-    def test_send(self, mock_zmq_context):
+    def test_send(self):
         msg = {'this': 'is',
                'a': 'test',
                'payload': 'PAYLOAD'}
         json_msg = json.dumps(msg)
         self.sender.send_message(msg)
-        publisher = self.sender.publisher
-        publisher.connect.assert_called_with('bindstr')
-        publisher.send.assert_called_with(json_msg)
+        mock_socket = self.mock_zmq_context.socket()
+
+        eq_(mock_socket.connect.call_count, 2)
+        eq_(mock_socket.connect.call_args, (('bindstr',), {}))
+        eq_(mock_socket.send.call_count, 1)
+
+        mock_socket.send.assert_called_with(json_msg)
+
+    def test_debug_stderr(self):
+        msg = {'milk': 'shake'}
+        json_msg = json.dumps(msg)
+        self.sender.debug_stderr = True
+        with patch('sys.stderr') as mock_stderr:
+            self.sender.send_message(msg)
+            eq_(mock_stderr.write.call_count, 1)
+            eq_(mock_stderr.flush.call_count, 1)
+            mock_stderr.write.assert_called_with(json_msg + '\n')
 
 
 @patch('sys.stdout')
